// Helper function to get the computed font size of an element
function getComputedFontSize(element) {
    return parseInt(window.getComputedStyle(element).fontSize);
}

// Helper function to set the font size of an element and update localStorage
function setFontSize(element, size, category) {
    element.style.fontSize = `${size}px`;
    localStorage.setItem(`userFontSize_${category}`, size); // Update the stored font size for the category
}

// Helper function to copy font size from content to settingsET
function copyFontSize() {
    const content = document.querySelector('.md-content__inner');
    const settingsET = document.querySelector('.settings-example-text');
    settingsET.style.fontSize = window.getComputedStyle(content).fontSize;
}

// Helper function to get the display size category
function getDisplaySizeCategory() {
    const width = window.innerWidth;
    if (width >= 1800) return 'large';
    if (width >= 1200) return 'medium';
    if (width >= 768) return 'tablet';
    return 'small';
}

// Event listener to initialize font size settings when the document is fully loaded
document.addEventListener('DOMContentLoaded', function() {
    const content = document.querySelector('.md-content__inner');
    
    const currentDisplaySizeCategory = getDisplaySizeCategory();

    // Retrieve the saved font size for the current display size category from localStorage, if available
    const savedFontSize = localStorage.getItem(`userFontSize_${currentDisplaySizeCategory}`);

    if (savedFontSize) {
        // Apply the saved font size to the content element
        setFontSize(content, savedFontSize, currentDisplaySizeCategory);
    }

    // Ensure settingsET copies the font size of content
    copyFontSize();
});

// Function to increase the font size of the content
function increaseFontSize() {
    const content = document.querySelector('.md-content__inner');
    
    // Retrieve the current font size, increase it by 2px, and apply the new size
    let currentSize = getComputedFontSize(content);
    let newSize = currentSize + 2;
    const category = getDisplaySizeCategory();
    setFontSize(content, newSize, category);
    
    // Ensure settingsET copies the new font size of content
    copyFontSize();

    // Adjust the Buttons-size and grid to match the new font size
    adjustButtonsGrid();
}

// Function to decrease the font size of the content
function decreaseFontSize() {
    const content = document.querySelector('.md-content__inner');
    
    // Retrieve the current font size, decrease it by 2px (minimum 12px), and apply the new size
    let currentSize = getComputedFontSize(content);
    let newSize = Math.max(currentSize - 2, 12);
    const category = getDisplaySizeCategory();
    setFontSize(content, newSize, category);
    
    // Ensure settingsET copies the new font size of content
    copyFontSize();
    
    // Adjust the Buttons-size and grid to match the new font size
    adjustButtonsGrid();
}

// Function to reset the font size to the CSS-defined value
function resetFontSize() {
    const content = document.querySelector('.md-content__inner');
    
    // Remove inline font size styles to revert to CSS-defined values
    content.style.fontSize = '';
    
    // Ensure settingsET copies the font size of content
    copyFontSize();
    
    // Delete the local storage entry for the current display size category
    const category = getDisplaySizeCategory();
    localStorage.removeItem(`userFontSize_${category}`);
    
    // Adjust the Buttons-size and grid to match the new font size
    adjustButtonsGrid();
}

// Event listener to adjust font size on window resize
window.addEventListener('resize', function() {
    const content = document.querySelector('.md-content__inner');
    
    const currentDisplaySizeCategory = getDisplaySizeCategory();
    const savedFontSize = localStorage.getItem(`userFontSize_${currentDisplaySizeCategory}`);
    
    if (savedFontSize) {
        setFontSize(content, savedFontSize, currentDisplaySizeCategory);
    } else {
        // Revert to CSS defined font size if no saved size is available for the current category
        content.style.fontSize = '';
    }
    
    // Ensure settingsET copies the font size of content
    copyFontSize();
});


